==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/FlowletArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.FlowletArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Data flow flowlet
 * @property annotations List of tags that can be used for describing the data flow.
 * @property description The description of the data flow.
 * @property folder The folder that this data flow is in. If not specified, Data flow will appear at the root level.
 * @property script Flowlet script.
 * @property scriptLines Flowlet script lines.
 * @property sinks List of sinks in Flowlet.
 * @property sources List of sources in Flowlet.
 * @property transformations List of transformations in Flowlet.
 * @property type Type of data flow.
 * Expected value is 'Flowlet'.
 */
public data class FlowletArgs(
    public val annotations: Output<List<Any>>? = null,
    public val description: Output<String>? = null,
    public val folder: Output<DataFlowFolderArgs>? = null,
    public val script: Output<String>? = null,
    public val scriptLines: Output<List<String>>? = null,
    public val sinks: Output<List<DataFlowSinkArgs>>? = null,
    public val sources: Output<List<DataFlowSourceArgs>>? = null,
    public val transformations: Output<List<TransformationArgs>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.FlowletArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.FlowletArgs =
        com.pulumi.azurenative.datafactory.inputs.FlowletArgs.builder()
            .annotations(annotations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .description(description?.applyValue({ args0 -> args0 }))
            .folder(folder?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .script(script?.applyValue({ args0 -> args0 }))
            .scriptLines(scriptLines?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .sinks(sinks?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .sources(
                sources?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .transformations(
                transformations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FlowletArgs].
 */
@PulumiTagMarker
public class FlowletArgsBuilder internal constructor() {
    private var annotations: Output<List<Any>>? = null

    private var description: Output<String>? = null

    private var folder: Output<DataFlowFolderArgs>? = null

    private var script: Output<String>? = null

    private var scriptLines: Output<List<String>>? = null

    private var sinks: Output<List<DataFlowSinkArgs>>? = null

    private var sources: Output<List<DataFlowSourceArgs>>? = null

    private var transformations: Output<List<TransformationArgs>>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of tags that can be used for describing the data flow.
     */
    @JvmName("cibuljhiygbfvrya")
    public suspend fun annotations(`value`: Output<List<Any>>) {
        this.annotations = value
    }

    @JvmName("nxjkytmxnulwicar")
    public suspend fun annotations(vararg values: Output<Any>) {
        this.annotations = Output.all(values.asList())
    }

    /**
     * @param values List of tags that can be used for describing the data flow.
     */
    @JvmName("njcylbstdslhjumh")
    public suspend fun annotations(values: List<Output<Any>>) {
        this.annotations = Output.all(values)
    }

    /**
     * @param value The description of the data flow.
     */
    @JvmName("kbjnrsuiwnxmolah")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("jypnfjbsuckomrpb")
    public suspend fun folder(`value`: Output<DataFlowFolderArgs>) {
        this.folder = value
    }

    /**
     * @param value Flowlet script.
     */
    @JvmName("genagejoeolrlqqw")
    public suspend fun script(`value`: Output<String>) {
        this.script = value
    }

    /**
     * @param value Flowlet script lines.
     */
    @JvmName("pxcvaxoxhrexusjd")
    public suspend fun scriptLines(`value`: Output<List<String>>) {
        this.scriptLines = value
    }

    @JvmName("bkgmqwswldqwmwvk")
    public suspend fun scriptLines(vararg values: Output<String>) {
        this.scriptLines = Output.all(values.asList())
    }

    /**
     * @param values Flowlet script lines.
     */
    @JvmName("xvtnhnnefrnjyhxm")
    public suspend fun scriptLines(values: List<Output<String>>) {
        this.scriptLines = Output.all(values)
    }

    /**
     * @param value List of sinks in Flowlet.
     */
    @JvmName("sdlqybqlgnmihrue")
    public suspend fun sinks(`value`: Output<List<DataFlowSinkArgs>>) {
        this.sinks = value
    }

    @JvmName("rkoyjodsmebtmdhs")
    public suspend fun sinks(vararg values: Output<DataFlowSinkArgs>) {
        this.sinks = Output.all(values.asList())
    }

    /**
     * @param values List of sinks in Flowlet.
     */
    @JvmName("yxedeskdrpmgggxs")
    public suspend fun sinks(values: List<Output<DataFlowSinkArgs>>) {
        this.sinks = Output.all(values)
    }

    /**
     * @param value List of sources in Flowlet.
     */
    @JvmName("isiuodsytqjuojte")
    public suspend fun sources(`value`: Output<List<DataFlowSourceArgs>>) {
        this.sources = value
    }

    @JvmName("hfkghbytiwwvvjbf")
    public suspend fun sources(vararg values: Output<DataFlowSourceArgs>) {
        this.sources = Output.all(values.asList())
    }

    /**
     * @param values List of sources in Flowlet.
     */
    @JvmName("jqpqsiakcmysmwjb")
    public suspend fun sources(values: List<Output<DataFlowSourceArgs>>) {
        this.sources = Output.all(values)
    }

    /**
     * @param value List of transformations in Flowlet.
     */
    @JvmName("ebljqnrwfdaefdpw")
    public suspend fun transformations(`value`: Output<List<TransformationArgs>>) {
        this.transformations = value
    }

    @JvmName("iuhkqcgrttkwwvgo")
    public suspend fun transformations(vararg values: Output<TransformationArgs>) {
        this.transformations = Output.all(values.asList())
    }

    /**
     * @param values List of transformations in Flowlet.
     */
    @JvmName("fysbwiqbwqkakrib")
    public suspend fun transformations(values: List<Output<TransformationArgs>>) {
        this.transformations = Output.all(values)
    }

    /**
     * @param value Type of data flow.
     * Expected value is 'Flowlet'.
     */
    @JvmName("rctddhtrsdvpgtrt")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of tags that can be used for describing the data flow.
     */
    @JvmName("gewuliibcojqpnnp")
    public suspend fun annotations(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param values List of tags that can be used for describing the data flow.
     */
    @JvmName("uwvcxwclqvtdnkjv")
    public suspend fun annotations(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param value The description of the data flow.
     */
    @JvmName("adreyxtcjyhswqed")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("lombjxadantfivor")
    public suspend fun folder(`value`: DataFlowFolderArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.folder = mapped
    }

    /**
     * @param argument The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("fdwfqhclxpqagfla")
    public suspend fun folder(argument: suspend DataFlowFolderArgsBuilder.() -> Unit) {
        val toBeMapped = DataFlowFolderArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.folder = mapped
    }

    /**
     * @param value Flowlet script.
     */
    @JvmName("hlgyulvtdltheyqp")
    public suspend fun script(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.script = mapped
    }

    /**
     * @param value Flowlet script lines.
     */
    @JvmName("anllpwxhjsswqnev")
    public suspend fun scriptLines(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scriptLines = mapped
    }

    /**
     * @param values Flowlet script lines.
     */
    @JvmName("xjsqgxrkqlmuhgjc")
    public suspend fun scriptLines(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scriptLines = mapped
    }

    /**
     * @param value List of sinks in Flowlet.
     */
    @JvmName("dbmyhbwulkjnsxpa")
    public suspend fun sinks(`value`: List<DataFlowSinkArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in Flowlet.
     */
    @JvmName("hhdsefrmkirwrqqw")
    public suspend fun sinks(argument: List<suspend DataFlowSinkArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataFlowSinkArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in Flowlet.
     */
    @JvmName("wwtfxerjlpuycojh")
    public suspend fun sinks(vararg argument: suspend DataFlowSinkArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataFlowSinkArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in Flowlet.
     */
    @JvmName("fxsckjygckvjolcv")
    public suspend fun sinks(argument: suspend DataFlowSinkArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataFlowSinkArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param values List of sinks in Flowlet.
     */
    @JvmName("olciyykftpkpwygg")
    public suspend fun sinks(vararg values: DataFlowSinkArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sinks = mapped
    }

    /**
     * @param value List of sources in Flowlet.
     */
    @JvmName("pptbkijwxqsdvffj")
    public suspend fun sources(`value`: List<DataFlowSourceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sources = mapped
    }

    /**
     * @param argument List of sources in Flowlet.
     */
    @JvmName("jrydlssdalkqsbuv")
    public suspend fun sources(argument: List<suspend DataFlowSourceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataFlowSourceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param argument List of sources in Flowlet.
     */
    @JvmName("mljcgcovvlrxdacx")
    public suspend fun sources(vararg argument: suspend DataFlowSourceArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataFlowSourceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param argument List of sources in Flowlet.
     */
    @JvmName("pvhsoxbbvisnnuqf")
    public suspend fun sources(argument: suspend DataFlowSourceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataFlowSourceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param values List of sources in Flowlet.
     */
    @JvmName("ddlyqatcptbwelcr")
    public suspend fun sources(vararg values: DataFlowSourceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sources = mapped
    }

    /**
     * @param value List of transformations in Flowlet.
     */
    @JvmName("bqxhlbyfrulvxrdl")
    public suspend fun transformations(`value`: List<TransformationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in Flowlet.
     */
    @JvmName("yuneawtotwldeebc")
    public suspend fun transformations(argument: List<suspend TransformationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TransformationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in Flowlet.
     */
    @JvmName("alhinrumuvfqoiis")
    public suspend fun transformations(
        vararg
        argument: suspend TransformationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TransformationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in Flowlet.
     */
    @JvmName("hrytnnywmmoeophs")
    public suspend fun transformations(argument: suspend TransformationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TransformationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param values List of transformations in Flowlet.
     */
    @JvmName("plckgoodgevatvqs")
    public suspend fun transformations(vararg values: TransformationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transformations = mapped
    }

    /**
     * @param value Type of data flow.
     * Expected value is 'Flowlet'.
     */
    @JvmName("fmolsagbwgcefruv")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): FlowletArgs = FlowletArgs(
        annotations = annotations,
        description = description,
        folder = folder,
        script = script,
        scriptLines = scriptLines,
        sinks = sinks,
        sources = sources,
        transformations = transformations,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/FlowletArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.FlowletArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Data flow flowlet
 * @property annotations List of tags that can be used for describing the data flow.
 * @property description The description of the data flow.
 * @property folder The folder that this data flow is in. If not specified, Data flow will appear at the root level.
 * @property script Flowlet script.
 * @property scriptLines Flowlet script lines.
 * @property sinks List of sinks in Flowlet.
 * @property sources List of sources in Flowlet.
 * @property transformations List of transformations in Flowlet.
 * @property type Type of data flow.
 * Expected value is 'Flowlet'.
 */
public data class FlowletArgs(
    public val annotations: Output<List<Any>>? = null,
    public val description: Output<String>? = null,
    public val folder: Output<DataFlowFolderArgs>? = null,
    public val script: Output<String>? = null,
    public val scriptLines: Output<List<String>>? = null,
    public val sinks: Output<List<DataFlowSinkArgs>>? = null,
    public val sources: Output<List<DataFlowSourceArgs>>? = null,
    public val transformations: Output<List<TransformationArgs>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.FlowletArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.FlowletArgs =
        com.pulumi.azurenative.datafactory.inputs.FlowletArgs.builder()
            .annotations(annotations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .description(description?.applyValue({ args0 -> args0 }))
            .folder(folder?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .script(script?.applyValue({ args0 -> args0 }))
            .scriptLines(scriptLines?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .sinks(sinks?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .sources(
                sources?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .transformations(
                transformations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FlowletArgs].
 */
@PulumiTagMarker
public class FlowletArgsBuilder internal constructor() {
    private var annotations: Output<List<Any>>? = null

    private var description: Output<String>? = null

    private var folder: Output<DataFlowFolderArgs>? = null

    private var script: Output<String>? = null

    private var scriptLines: Output<List<String>>? = null

    private var sinks: Output<List<DataFlowSinkArgs>>? = null

    private var sources: Output<List<DataFlowSourceArgs>>? = null

    private var transformations: Output<List<TransformationArgs>>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of tags that can be used for describing the data flow.
     */
    @JvmName("icwgoonflxhowdsl")
    public suspend fun annotations(`value`: Output<List<Any>>) {
        this.annotations = value
    }

    @JvmName("nodtcyvajkbdwccc")
    public suspend fun annotations(vararg values: Output<Any>) {
        this.annotations = Output.all(values.asList())
    }

    /**
     * @param values List of tags that can be used for describing the data flow.
     */
    @JvmName("kopwrbkpqwutyqap")
    public suspend fun annotations(values: List<Output<Any>>) {
        this.annotations = Output.all(values)
    }

    /**
     * @param value The description of the data flow.
     */
    @JvmName("cbcxyxecdomkloxl")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("fpbmgfogbwmcannv")
    public suspend fun folder(`value`: Output<DataFlowFolderArgs>) {
        this.folder = value
    }

    /**
     * @param value Flowlet script.
     */
    @JvmName("yocaobdyemolfvtf")
    public suspend fun script(`value`: Output<String>) {
        this.script = value
    }

    /**
     * @param value Flowlet script lines.
     */
    @JvmName("cudktelvuhyhpryx")
    public suspend fun scriptLines(`value`: Output<List<String>>) {
        this.scriptLines = value
    }

    @JvmName("owtpcxhmtubttjrh")
    public suspend fun scriptLines(vararg values: Output<String>) {
        this.scriptLines = Output.all(values.asList())
    }

    /**
     * @param values Flowlet script lines.
     */
    @JvmName("lwqcwfnildhhkldn")
    public suspend fun scriptLines(values: List<Output<String>>) {
        this.scriptLines = Output.all(values)
    }

    /**
     * @param value List of sinks in Flowlet.
     */
    @JvmName("maymvbqmctiugjbs")
    public suspend fun sinks(`value`: Output<List<DataFlowSinkArgs>>) {
        this.sinks = value
    }

    @JvmName("mkmhvthnbkiddmos")
    public suspend fun sinks(vararg values: Output<DataFlowSinkArgs>) {
        this.sinks = Output.all(values.asList())
    }

    /**
     * @param values List of sinks in Flowlet.
     */
    @JvmName("oordkelyxiokfvta")
    public suspend fun sinks(values: List<Output<DataFlowSinkArgs>>) {
        this.sinks = Output.all(values)
    }

    /**
     * @param value List of sources in Flowlet.
     */
    @JvmName("erfmbkjdwtxmmpdl")
    public suspend fun sources(`value`: Output<List<DataFlowSourceArgs>>) {
        this.sources = value
    }

    @JvmName("itehnsthevpiudov")
    public suspend fun sources(vararg values: Output<DataFlowSourceArgs>) {
        this.sources = Output.all(values.asList())
    }

    /**
     * @param values List of sources in Flowlet.
     */
    @JvmName("pbjdutjvuqnvqtff")
    public suspend fun sources(values: List<Output<DataFlowSourceArgs>>) {
        this.sources = Output.all(values)
    }

    /**
     * @param value List of transformations in Flowlet.
     */
    @JvmName("lmuxmmbhepywgdll")
    public suspend fun transformations(`value`: Output<List<TransformationArgs>>) {
        this.transformations = value
    }

    @JvmName("kkbygwjfinhhpnxw")
    public suspend fun transformations(vararg values: Output<TransformationArgs>) {
        this.transformations = Output.all(values.asList())
    }

    /**
     * @param values List of transformations in Flowlet.
     */
    @JvmName("upbttxonijwkjoyn")
    public suspend fun transformations(values: List<Output<TransformationArgs>>) {
        this.transformations = Output.all(values)
    }

    /**
     * @param value Type of data flow.
     * Expected value is 'Flowlet'.
     */
    @JvmName("dkiugeilavwhwfbr")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of tags that can be used for describing the data flow.
     */
    @JvmName("llrtamcrvlkhvpqs")
    public suspend fun annotations(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param values List of tags that can be used for describing the data flow.
     */
    @JvmName("kfakytyylsuwvefy")
    public suspend fun annotations(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param value The description of the data flow.
     */
    @JvmName("wqaxepimtoqbkhlh")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("tvtfynjrjucduxnp")
    public suspend fun folder(`value`: DataFlowFolderArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.folder = mapped
    }

    /**
     * @param argument The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("vnqohecjfvkcwcjy")
    public suspend fun folder(argument: suspend DataFlowFolderArgsBuilder.() -> Unit) {
        val toBeMapped = DataFlowFolderArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.folder = mapped
    }

    /**
     * @param value Flowlet script.
     */
    @JvmName("jbqbppdsdukmgptt")
    public suspend fun script(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.script = mapped
    }

    /**
     * @param value Flowlet script lines.
     */
    @JvmName("lehqwlanitxdscjh")
    public suspend fun scriptLines(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scriptLines = mapped
    }

    /**
     * @param values Flowlet script lines.
     */
    @JvmName("fukpclwijndjyqyl")
    public suspend fun scriptLines(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scriptLines = mapped
    }

    /**
     * @param value List of sinks in Flowlet.
     */
    @JvmName("hphlypcyxhftjavd")
    public suspend fun sinks(`value`: List<DataFlowSinkArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in Flowlet.
     */
    @JvmName("qrovrtnhwjunmpfn")
    public suspend fun sinks(argument: List<suspend DataFlowSinkArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataFlowSinkArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in Flowlet.
     */
    @JvmName("wlyhnphkybxauspq")
    public suspend fun sinks(vararg argument: suspend DataFlowSinkArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataFlowSinkArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in Flowlet.
     */
    @JvmName("qtjyeobladicvncn")
    public suspend fun sinks(argument: suspend DataFlowSinkArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataFlowSinkArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param values List of sinks in Flowlet.
     */
    @JvmName("cmxksrxoppvnnudr")
    public suspend fun sinks(vararg values: DataFlowSinkArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sinks = mapped
    }

    /**
     * @param value List of sources in Flowlet.
     */
    @JvmName("okwsouwinjiaacri")
    public suspend fun sources(`value`: List<DataFlowSourceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sources = mapped
    }

    /**
     * @param argument List of sources in Flowlet.
     */
    @JvmName("evkrfuvypramopcx")
    public suspend fun sources(argument: List<suspend DataFlowSourceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataFlowSourceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param argument List of sources in Flowlet.
     */
    @JvmName("knfmkuafvdxrmqvk")
    public suspend fun sources(vararg argument: suspend DataFlowSourceArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataFlowSourceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param argument List of sources in Flowlet.
     */
    @JvmName("nctbcuyxbyumjrjx")
    public suspend fun sources(argument: suspend DataFlowSourceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataFlowSourceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param values List of sources in Flowlet.
     */
    @JvmName("jocwbgnkkxhdbbej")
    public suspend fun sources(vararg values: DataFlowSourceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sources = mapped
    }

    /**
     * @param value List of transformations in Flowlet.
     */
    @JvmName("dxalwjohppgygvap")
    public suspend fun transformations(`value`: List<TransformationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in Flowlet.
     */
    @JvmName("utfyxalmiaduurqq")
    public suspend fun transformations(argument: List<suspend TransformationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TransformationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in Flowlet.
     */
    @JvmName("ulbsquykamamhroq")
    public suspend fun transformations(
        vararg
        argument: suspend TransformationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TransformationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in Flowlet.
     */
    @JvmName("woxaoxakxslowfxn")
    public suspend fun transformations(argument: suspend TransformationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TransformationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param values List of transformations in Flowlet.
     */
    @JvmName("jyutrmutjbnallvn")
    public suspend fun transformations(vararg values: TransformationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transformations = mapped
    }

    /**
     * @param value Type of data flow.
     * Expected value is 'Flowlet'.
     */
    @JvmName("jtleaowushixktgr")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): FlowletArgs = FlowletArgs(
        annotations = annotations,
        description = description,
        folder = folder,
        script = script,
        scriptLines = scriptLines,
        sinks = sinks,
        sources = sources,
        transformations = transformations,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
